import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';
import getRootClassName from './utils/getRootClassName';


export default ({
    block,
    displayName,
    Spinner,
    uiPropDefaultType = PropTypes.string,
    uiPropDefaultValue = '',
    uiPropGetValue = (ui) => ui
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');
    invariant(Spinner !== undefined, 'Missing Spinner component.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.shape({
                    name: PropTypes.string.isRequired,
                    direction: PropTypes.oneOf(['left', 'right'])
                })
            ]),
            loading: PropTypes.bool,
            toggled: PropTypes.bool,
            type: PropTypes.oneOf([
                'button',
                'submit'
            ]),
            ui: uiPropDefaultType
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                icon: null,
                loading: false,
                toggled: false,
                type: 'button',
                ui: uiPropDefaultValue
            };
        },

        render() {
            const { children, disabled, icon, loading, toggled, type, ui, ...rest } = this.props;
            return (
                <button
                    { ...rest }
                    type={ type }
                    className={ getRootClassName(block, { children, icon, ui: uiPropGetValue(ui) }, { disabled, loading, toggled }) }
                    disabled={ disabled || loading }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                    <div className={ block('spinner') }>
                        <Spinner />
                    </div>
                </button>
            );
        }

    });

};
