import test from 'tape';

import toNumber from './toNumber';


test('float: non-number as string', (t) => {
    const result = toNumber('x', 'float');
    t.same(result, { value: '', valid: false });
    t.end();
});

test('float: number as string', (t) => {
    const result = toNumber('1', 'float');
    t.same(result, { value: 1, valid: true });
    t.end();
});

test('float: comma', (t) => {
    const result = toNumber('11,11', 'float');
    t.same(result, { value: 11.11, valid: true });
    t.end();
});

test('float: dot', (t) => {
    const result = toNumber('11.11', 'float');
    t.same(result, { value: 11.11, valid: true });
    t.end();
});

test('float: minus', (t) => {
    const result = toNumber('-', 'float');
    t.same(result, { value: 0, valid: true });
    t.end();
});

test('float: multiple minuses', (t) => {
    const result = toNumber('--', 'float');
    t.same(result, { value: '', valid: false });
    t.end();
});


test('integer: non-number as string', (t) => {
    const result = toNumber('x', 'integer');
    t.same(result, { value: '', valid: false });
    t.end();
});

test('integer: number as string', (t) => {
    const result = toNumber('1', 'integer');
    t.same(result, { value: 1, valid: true });
    t.end();
});

test('integer: comma', (t) => {
    const result = toNumber('11,11', 'integer');
    t.same(result, { value: '', valid: false });
    t.end();
});

test('integer: dot', (t) => {
    const result = toNumber('11.11', 'integer');
    t.same(result, { value: '', valid: false });
    t.end();
});

test('float: minus', (t) => {
    const result = toNumber('-', 'integer');
    t.same(result, { value: 0, valid: true });
    t.end();
});

test('float: multiple minuses', (t) => {
    const result = toNumber('--', 'integer');
    t.same(result, { value: '', valid: false });
    t.end();
});
